@@ -53,9 +53,13 @@ class Hub:
         self.args = args
         self.cwd = py.path.local()
         self.quiet = False
-        self._last_http_status = None
+        self._last_http_stati = []
         self.http = new_requests_session(agent=("client", client_version))
 
+    @property
+    def _last_http_status(self):
+        return self._last_http_stati[-1]
+
     def set_quiet(self):
         self.quiet = True
 
@@ -99,9 +103,10 @@ class Hub:
             r = self.http.request(method, url, data=data, headers=headers,
                                   auth=basic_auth, cert=cert)
         except self.http.Errors as e:
-            self._last_http_status = -1
+            self._last_http_stati.append(-1)
             self.fatal("could not connect to %r:\n%s" % (url, e))
-        self._last_http_status = r.status_code
+        else:
+            self._last_http_stati.append(r.status_code)
 
         if r.url != url:
             self.info("*redirected: %s" %(r.url,))
@@ -477,7 +482,9 @@ def use(parser):
              "given url.  If already connected to a server, you can "
              "specify '/USER/INDEXNAME' which will use the same server "
              "context. If you specify the root url you will not be connected "
-             "to a particular index. ")
+             "to a particular index. If you have a web server with basic auth "
+             "in front of devpi-server, then use a url like this: "
+             "https://username:password@example.com/USER/INDEXNAME")
 
 @subcommand("devpi.getjson")
 def getjson(parser):
@@ -635,7 +642,9 @@ def upload(parser):
 
     build.add_argument("--no-vcs", action="store_true", dest="novcs",
         help="don't VCS-export to a fresh dir, just execute setup.py scripts "
-             "directly using their dirname as current dir. ")
+             "directly using their dirname as current dir. By default "
+             "git/hg/svn/bazaar are auto-detected and packaging is run from "
+             "a fresh directory with all versioned files exported.")
 
     build.add_argument("--formats", default=default_format, action="store",
         help="comma separated list of build formats (passed to setup.py). "
